@@ -1,13 +1,14 @@
 # Deb-o-Matic
 #
-# Copyright (C) 2007-2018 Luca Falavigna
+# Copyright (C) 2007-2022 Luca Falavigna
 # Copyright (C) 2010 Alessio Treglia
 #
 # Author: Luca Falavigna <dktrkranz@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 3 of the License.
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option), any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -22,8 +23,9 @@ import os
 from ast import literal_eval
 from contextlib import contextmanager
 from logging import debug, error, info
+from pwd import getpwnam
 from re import findall, match, search, sub
-from shutil import copy, copymode, move, rmtree
+from shutil import chown, copy, copymode, move, rmtree
 from subprocess import Popen, check_output
 from tempfile import NamedTemporaryFile
 from threading import Semaphore
@@ -49,9 +51,7 @@ class BuildTask:
 
     def __enter__(self):
         for task in self._queue:
-            if (self._package == task._package and
-               self._version == task._version and
-               self._distribution == task._distribution):
+            if self.match(task._package, task._version, task._distribution):
                 info(_('Build already scheduled for '
                        'package %(package)s_%(version)s in %(dist)s') %
                      {'package': self._package, 'version': self._version,
@@ -86,10 +86,9 @@ class BuildTask:
             self._pid = 0
 
     def match(self, package, version, distribution):
-        if (self._package == package and
+        return (self._package == package and
            self._version == version and
-           self._distribution == distribution):
-            return self
+           self._distribution == distribution)
 
 
 class Build:
@@ -97,6 +96,8 @@ class Build:
     def __init__(self, changesfile=None, package=None, distribution=None,
                  binnmu=None, extrabd=None, maintainer=None, origin=None,
                  uploader=None):
+        self.uid = None
+        self.gid = None
         self.buildtask = None
         self.changesfile = changesfile
         self.package = package
@@ -113,6 +114,12 @@ class Build:
         self.dpr = False
 
     def _build(self):
+        try:
+            self.uid = getpwnam(dom.opts.get('debomatic', 'builduser')).pw_uid
+            self.gid = getpwnam('sbuild').pw_gid
+        except KeyError:
+            self.uid = 0
+            self.gid = 0
         self._parse_distribution()
         if self.distribution in dom.opts.get('distributions', 'blacklist'):
             self._remove_files()
@@ -141,8 +148,7 @@ class Build:
         uploader_email = ''
         packageversion = os.path.splitext(os.path.basename(self.dscfile))[0]
         builddir = os.path.join(self.poolpath, 'pool', packageversion)
-        if not os.path.exists(builddir):
-            os.makedirs(builddir)
+        self._makedirs(builddir, True)
         if self.uploader:
             uploader_email = self.uploader[1].decode('utf-8')
         architecture = dom.opts.get('debomatic', 'architecture')
@@ -188,18 +194,18 @@ class Build:
         if self.changesfile:
             with open(self.upload, 'r') as fd:
                 data = fd.read()
-            for file in findall('\s\w{32}\s\d+\s\S+\s\S+\s(.*)', data):
+            for file in findall(r'\s\w{32}\s\d+\s\S+\s\S+\s(.*)', data):
                 if '.orig.' in file:
                     command.insert(-1, '--force-orig-source')
                     break
             try:
                 command.insert(-1, '--debbuildopt=-v%s~' %
-                               findall(' \S+ \((\S+)\) \S+; ', data)[-1])
+                               findall(r' \S+ \((\S+)\) \S+; ', data)[-1])
             except IndexError:
                 pass
             with open(os.path.join(self.incoming, self.changesfile)) as fd:
                 data = fd.read()
-            for resolver in findall('Debomatic-Resolver: (\S+)', data):
+            for resolver in findall(r'Debomatic-Resolver: (\S+)', data):
                 command.insert(-1, '--build-dep-resolver=%s' % resolver)
         if self.binnmu:
             command.insert(-1, '--binNMU=%s' % self.binnmu[0])
@@ -210,7 +216,7 @@ class Build:
         else:
             buildlog = '%s_%s.build' % (packageversion, architecture)
         if self.hostarchitecture:
-            buildlog = sub('(.*_)\S+(\.build)',
+            buildlog = sub(r'(.*_)\S+(\.build)',
                            '\\1%s\\2' % self.hostarchitecture, buildlog)
         if self.maintainer:
             command.remove('-A')
@@ -219,7 +225,7 @@ class Build:
         ext = {'.gz': 'gzip', '.bz2': 'bzip2', '.xz': 'xz'}
         for file in self.files:
             if os.path.isfile(file):
-                if findall('(.*\.debian\..*)', file):
+                if findall(r'(.*\.debian\..*)', file):
                     try:
                         command.insert(-1, '--debbuildopt=-Z%s' %
                                        ext[os.path.splitext(file)[1]])
@@ -240,7 +246,9 @@ class Build:
                 if os.path.exists(buildlink):
                     os.unlink(buildlink)
                 os.symlink(buildlog, buildlink)
-                process = Popen(command, stdout=fd, stderr=fd, cwd=ppath)
+                process = Popen(command, stdout=fd, stderr=fd, cwd=ppath,
+                                preexec_fn=self._demote(),
+                                start_new_session=True)
                 with self.buildtask.set_pid(process.pid):
                     process.wait()
                 if process.returncode:
@@ -278,11 +286,17 @@ class Build:
             commands.append('--log-external-command-error')
         return commands
 
+    def _demote(self):
+        def result():
+            os.setgid(self.gid)
+            os.setuid(self.uid)
+        return result
+
     def _fetch_files(self):
 
         def _download_files(mirror, component, package, file, filepath):
             request = Request('%s/pool/%s/%s/%s/%s' % (mirror, component,
-                              findall('^lib\S|^\S', package)[0],
+                              findall(r'^lib\S|^\S', package)[0],
                               package, file))
             try:
                 debug(_('Requesting URL %s') % request.get_full_url())
@@ -307,7 +321,7 @@ class Build:
                 raise DebomaticError
         else:
             package = self.package[0]
-            version = sub('^\d+\:', '', self.package[1])
+            version = sub(r'^\d+\:', '', self.package[1])
             dscfile = '%s_%s.dsc' % (package, version)
             if not dom.dists.has_section(self.origin):
                 error(_('Distribution %s not configured') % self.distribution)
@@ -329,7 +343,7 @@ class Build:
             raise DebomaticError
         with open(self.dscfile, 'r') as fd:
             data = fd.read()
-        for entry in findall('\s\w{32}\s\d+\s(\S+)', data):
+        for entry in findall(r'\s\w{32}\s\d+\s(\S+)', data):
             if not os.path.isfile(os.path.join(self.incoming, entry)):
                 debug(_('Downloading missing %s') % entry)
                 for component in dom.dists.get(self.origin,
@@ -354,6 +368,16 @@ class Build:
         dom.chroots[chrootname].acquire()
 
     def _map_distribution(self):
+        if dom.opts.has_section('dpr'):
+            if dom.opts.getboolean('dpr', 'dpr'):
+                self.suite = self.distribution
+                if match(r'%s-\S+-\S+' %
+                         dom.opts.get('dpr', 'prefix'), self.suite):
+                    self.dpr = True
+                    self.distribution = '-'.join(
+                        self.distribution.split('-')[2:])
+                    if self.origin == self.suite:
+                        self.origin = self.distribution
         if dom.opts.has_option('distributions', 'mapper'):
             try:
                 mapper = literal_eval(dom.opts.get('distributions', 'mapper'))
@@ -365,16 +389,24 @@ class Build:
                           {'mapped': self.distribution,
                            'mapper': mapper[self.distribution]})
                     self.distribution = mapper[self.distribution]
-        if dom.opts.has_section('dpr'):
-            if dom.opts.getboolean('dpr', 'dpr'):
-                self.suite = self.distribution
-                if match('%s-\S+-\S+' %
-                         dom.opts.get('dpr', 'prefix'), self.suite):
-                    self.dpr = True
-                    self.distribution = '-'.join(
-                        self.distribution.split('-')[2:])
-                    if self.origin == self.suite:
-                        self.origin = self.distribution
+                if self.origin and self.origin in mapper:
+                    debug(_('%(mapped)s mapped as %(mapper)s') %
+                          {'mapped': self.origin,
+                           'mapper': mapper[self.origin]})
+                    self.origin = mapper[self.origin]
+
+    def _makedirs(self, directory, change_owner=False):
+        os.makedirs(directory, exist_ok=True)
+        if change_owner:
+            chown(directory, user=self.uid)
+            for root, dirs, files in os.walk(directory):
+                try:
+                    for name in dirs:
+                        chown(os.path.join(root, name), user=self.uid)
+                    for name in files:
+                        chown(os.path.join(root, name), user=self.uid)
+                except FileNotFoundError:
+                    continue
 
     def _parse_distribution(self):
         if not self.distribution:
@@ -385,7 +417,7 @@ class Build:
                 error(_('Unable to open %s') % self.upload)
                 raise DebomaticError
             try:
-                dist = findall('Distribution:\s+(\S+)', data)[0]
+                dist = findall(r'Distribution:\s+(\S+)', data)[0]
                 self.distribution = dist.lower()
             except IndexError:
                 error(_('Bad .changes file: %s') % self.upload)
@@ -397,7 +429,7 @@ class Build:
             raise DebomaticError
         if self.origin:
             if not dom.dists.has_section(self.origin):
-                error(_('Distribution %s not configured') % self.distribution)
+                error(_('Distribution %s not configured') % self.origin)
                 raise DebomaticError
         else:
             self.origin = self.distribution
@@ -413,10 +445,8 @@ class Build:
     def _setup_chroot(self):
         action = None
         self.buildpath = os.path.join(self.incoming, self.distribution)
-        if not os.path.exists(self.buildpath):
-            os.makedirs(self.buildpath)
-        if not os.path.exists(self.poolpath):
-            os.makedirs(self.poolpath)
+        self._makedirs(self.buildpath)
+        self._makedirs(self.poolpath)
         architecture = dom.opts.get('debomatic', 'architecture')
         if architecture == 'system':
             b_arch = check_output(['dpkg-architecture', '-qDEB_BUILD_ARCH'])
@@ -436,8 +466,7 @@ class Build:
         mod.args.dists = dom.dists
         mod.execute_hook('pre_chroot')
         for d in ('logs', 'pool'):
-            if not os.path.exists(os.path.join(self.buildpath, d)):
-                os.makedirs(os.path.join(self.buildpath, d))
+            self._makedirs(os.path.join(self.buildpath, d))
         if action:
             profile = dom.opts.get('chroots', 'profile')
             if not os.path.isdir(os.path.join('/etc/schroot', profile)):
@@ -541,7 +570,7 @@ class Build:
                 error(_('Unable to open %s') % self.upload)
                 raise DebomaticError
             try:
-                for entry in findall('\s\w{32}\s\d+\s\S+\s\S+\s(.*)', data):
+                for entry in findall(r'\s\w{32}\s\d+\s\S+\s\S+\s(.*)', data):
                     entry = os.path.join(self.incoming, entry)
                     self.files.add(entry)
                     debug(_('File %s added') % entry)
