@@ -1,12 +1,13 @@
 # Deb-o-Matic
 #
-# Copyright (C) 2007-2018 Luca Falavigna
+# Copyright (C) 2007-2022 Luca Falavigna
 #
 # Author: Luca Falavigna <dktrkranz@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 3 of the License.
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option), any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -51,12 +52,13 @@ class Command():
         with open(self.cmdfile, 'r') as fd:
             cmd = fd.read()
         os.remove(self.cmdfile)
-        cmd_nmu = findall('\s?binnmu\s+(\S+_\S+) (\S+) (\d+) "(.*)" (.*)', cmd)
-        cmd_builddep = findall('\s?builddep\s+(\S+_\S+) (\S+) (.*)', cmd)
-        cmd_kill = findall('\s?kill\s+(\S+_\S+) (\S+)', cmd)
-        cmd_porter = findall('\s?porter\s+(\S+_\S+) (\S+) (.*)', cmd)
-        cmd_rebuild = findall('\s?rebuild\s+(\S+_\S+) (\S+) ?(\S*)', cmd)
-        cmd_rm = findall('\s?rm\s+(.*)', cmd)
+        cmd_nmu = findall(r'\s?binnmu\s+(\S+_\S+) (\S+) (\d+) "(.*)" (.*)',
+                          cmd)
+        cmd_builddep = findall(r'\s?builddep\s+(\S+_\S+) (\S+) (.*)', cmd)
+        cmd_kill = findall(r'\s?kill\s+(\S+_\S+) (\S+)', cmd)
+        cmd_porter = findall(r'\s?porter\s+(\S+_\S+) (\S+) (.*)', cmd)
+        cmd_rebuild = findall(r'\s?rebuild\s+(\S+_\S+) (\S+) ?(\S*)', cmd)
+        cmd_rm = findall(r'\s?rm\s+(.*)', cmd)
         if cmd_nmu:
             self._process_binnmu(cmd_nmu)
         if cmd_builddep:
