@@ -1,12 +1,13 @@
 # Deb-o-Matic
 #
-# Copyright (C) 2015-2018 Luca Falavigna
+# Copyright (C) 2015-2022 Luca Falavigna
 #
 # Author: Luca Falavigna <dktrkranz@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 3 of the License.
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option), any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -27,9 +28,9 @@ from .exceptions import DebomaticConffileError
 
 
 core = {'debomatic':
-        {'debootstrap': str, 'incoming': str, 'architecture': str,
-         'threads': int, 'inotify': bool, 'sleep': int, 'interval': int,
-         'logfile': str, 'loglevel': str},
+        {'builduser': str, 'debootstrap': str, 'incoming': str,
+         'architecture': str, 'threads': int, 'inotify': bool, 'sleep': int,
+         'interval': int, 'logfile': str, 'loglevel': str},
         'distributions': {'list': str, 'blacklist': str, 'mapper': dict},
         'chroots': {'profile': str, 'commands': str},
         'gpg': {'gpg': bool, 'keyring': str},
