@@ -1,13 +1,14 @@
 # Deb-o-Matic
 #
 # Copyright (C) 2008-2009 David Futcher
-# Copyright (C) 2012-2018 Luca Falavigna
+# Copyright (C) 2012-2022 Luca Falavigna
 #
 # Author: David Futcher <bobbo@ubuntu.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 3 of the License.
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option), any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -63,8 +64,8 @@ class Module():
         modules = set()
         try:
             for p in mod_path.split(':'):
-                modules |= set([os.path.splitext(os.path.basename(m))[0] for m in
-                               glob(os.path.join(p, '*.py'))])
+                modules |= set([os.path.splitext(os.path.basename(m))[0]
+                               for m in glob(os.path.join(p, '*.py'))])
         except OSError:
             self._use_modules = False
         if not modules:
@@ -200,7 +201,7 @@ class Module():
         try:
             return [m for m in toposort(modules) if m in self._instances]
         except ValueError as e:
-            circular = findall('.*?\(\'?(\S+?)\'?,', e.args[0])
+            circular = findall(r'.*?\(\'?(\S+?)\'?,', e.args[0])
             for instance in circular:
                 self._instances[instance]._disabled = True
             debug(_('Circular dependencies found, disabled modules: %s')
