@@ -1,13 +1,14 @@
 # Deb-o-Matic - Blhc module
 #
 # Copyright (C) 2014 Mattia Rizzolo
-# Copyright (C) 2015-2018 Luca Falavigna
+# Copyright (C) 2015-2022 Luca Falavigna
 #
 # Authors: Mattia Rizzolo <mattia@mapreri.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 3 of the License.
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option), any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -33,6 +34,8 @@ class DebomaticModule_Blhc:
         self.blhc = '/usr/bin/blhc'
 
     def post_build(self, args):
+        if not args.success:
+            return
         if args.opts.has_section('blhc') and \
            args.opts.has_option('blhc', 'options'):
             blhcopts = args.opts.get('blhc', 'options').strip().split()
